pyxtuml |Build Status| |Coverage Status|
========================================

pyxtuml is a python library for parsing, manipulating, and generating
`BridgePoint <https://www.xtuml.org>`__ xtUML models.

.. sectnum::

=============
Documentation
=============

Information on how to use pyxtuml is available at `Read the Docs <http://pyxtuml.readthedocs.io>`__.

==============
Reporting bugs
==============

If you encounter problems with pyxtuml, please `file a github
issue <https://github.com/xtuml/pyxtuml/issues/new>`__. If you
plan on sending pull request which affect more than a few lines of code,
please file an issue before you start to work on you changes. This will
allow us to discuss the solution properly before you commit time and
effort.

=======
License
=======

pyxtuml is licensed under the LGPLv3+, see COPYING and COPYING.LESSER
for more information.

.. |Build Status| image:: https://github.com/xtuml/pyxtuml/actions/workflows/run-tests.yaml/badge.svg
.. |Coverage Status| image:: https://coveralls.io/repos/xtuml/pyxtuml/badge.svg?branch=master
   :target: https://coveralls.io/r/xtuml/pyxtuml?branch=master
